@@ -10,8 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import unicode_literals
-
 import logging
 
 from django.conf import settings
@@ -64,8 +62,8 @@ class Audit(base.APIDictWrapper):
         self._request = request
 
     @classmethod
-    def create(cls, request, audit_template_uuid,
-               audit_type, auto_trigger=False, interval=None):
+    def create(cls, request, audit_template_uuid, audit_type, name=None,
+               auto_trigger=False, interval=None):
 
         """Create an audit in Watcher
 
@@ -91,11 +89,11 @@ class Audit(base.APIDictWrapper):
         if interval:
             return watcherclient(request).audit.create(
                 audit_template_uuid=audit_template_uuid, audit_type=audit_type,
-                auto_trigger=auto_trigger, interval=interval)
+                auto_trigger=auto_trigger, interval=interval, name=name)
         else:
             return watcherclient(request).audit.create(
                 audit_template_uuid=audit_template_uuid, audit_type=audit_type,
-                auto_trigger=auto_trigger)
+                auto_trigger=auto_trigger, name=name)
 
     @classmethod
     def list(cls, request, **filters):
@@ -127,7 +125,7 @@ class Audit(base.APIDictWrapper):
                  the ID
         :rtype:  :py:class:`~.Audit`
         """
-        return watcherclient(request).audit.get(audit_id=audit_id)
+        return watcherclient(request).audit.get(audit=audit_id)
 
     @classmethod
     def delete(cls, request, audit_id):
@@ -139,7 +137,7 @@ class Audit(base.APIDictWrapper):
         :param audit_id: audit id
         :type  audit_id: int
         """
-        watcherclient(request).audit.delete(audit_id=audit_id)
+        return watcherclient(request).audit.delete(audit=audit_id)
 
     @property
     def id(self):
@@ -516,7 +514,7 @@ class EfficacyIndicator(base.APIDictWrapper):
 
     def __init__(self, indicator):
         super(EfficacyIndicator, self).__init__(indicator)
-        self.value = indicator.get('value', None)
-        self.name = indicator.get('name', None)
-        self.description = indicator.get('description', None)
-        self.unit = indicator.get('unit', None)
+        self.value = getattr(indicator, 'value', None)
+        self.name = getattr(indicator, 'name', None)
+        self.description = getattr(indicator, 'description', None)
+        self.unit = getattr(indicator, 'unit', None)
