@@ -16,7 +16,7 @@
 import json
 import logging
 
-from django.core.urlresolvers import reverse_lazy
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 import horizon.exceptions
 from horizon import forms
